@@ -1,6 +1,7 @@
 from .claims import Claims
 from .cose import COSE
 from .cose_key import COSEKey
+from .cose_message import COSEMessage
 from .cwt import (
     CWT,
     decode,
@@ -11,12 +12,13 @@ from .cwt import (
     set_private_claim_names,
 )
 from .encrypted_cose_key import EncryptedCOSEKey
+from .enums import COSEType
 from .exceptions import CWTError, DecodeError, EncodeError, VerifyError
 from .helpers.hcert import load_pem_hcert_dsc
 from .recipient import Recipient
 from .signer import Signer
 
-__version__ = "2.1.0"
+__version__ = "2.3.0"
 __title__ = "cwt"
 __description__ = "A Python implementation of CWT/COSE"
 __url__ = "https://python-cwt.readthedocs.io"
@@ -35,7 +37,11 @@ __all__ = [
     "set_private_claim_names",
     "CWT",
     "COSE",
+    "COSEHeaders",
     "COSEKey",
+    "COSEMessage",
+    "COSESignature",
+    "COSEType",
     "EncryptedCOSEKey",
     "HPKECipherSuite",
     "Claims",
