@@ -135,7 +135,7 @@ class CWT(CBORProcessor):
         claims: Union[Claims, Dict[str, Any], Dict[int, Any], bytes],
         key: COSEKeyInterface,
         nonce: bytes = b"",
-        recipients: Optional[List[RecipientInterface]] = None,
+        recipients: List[RecipientInterface] = [],
         signers: List[Signer] = [],
         tagged: bool = False,
     ) -> bytes:
@@ -156,8 +156,7 @@ class CWT(CBORProcessor):
                 claims object, or a JWT claims object, text string or byte string.
             key (COSEKeyInterface): A COSE key used to generate a MAC for the claims.
             nonce (bytes): A nonce for encryption.
-            recipients (Optional[List[RecipientInterface]]): A list of recipient
-                information structures.
+            recipients (List[RecipientInterface]): A list of recipient information structures.
             signers (List[Signer]): A list of signer information structures for
                 multiple signer cases.
             tagged (bool): An indicator whether the response is wrapped by CWT
@@ -196,7 +195,7 @@ class CWT(CBORProcessor):
         self,
         claims: Union[Claims, Dict[int, Any], bytes],
         key: COSEKeyInterface,
-        recipients: Optional[List[RecipientInterface]] = None,
+        recipients: List[RecipientInterface] = [],
         tagged: bool = False,
     ) -> bytes:
         """
@@ -269,7 +268,7 @@ class CWT(CBORProcessor):
         claims: Union[Claims, Dict[int, Any], bytes],
         key: COSEKeyInterface,
         nonce: bytes = b"",
-        recipients: Optional[List[RecipientInterface]] = None,
+        recipients: List[RecipientInterface] = [],
         tagged: bool = False,
     ) -> bytes:
         """
@@ -367,7 +366,7 @@ class CWT(CBORProcessor):
         claims: Union[Claims, Dict[Any, Any], bytes],
         key: COSEKeyInterface,
         nonce: bytes = b"",
-        recipients: Optional[List[RecipientInterface]] = None,
+        recipients: List[RecipientInterface] = [],
         signers: List[Signer] = [],
         tagged: bool = False,
     ) -> bytes:
@@ -440,21 +439,19 @@ def encode(
     claims: Union[Claims, Dict[str, Any], Dict[int, Any], bytes],
     key: COSEKeyInterface,
     nonce: bytes = b"",
-    recipients: Optional[List[RecipientInterface]] = None,
+    recipients: List[RecipientInterface] = [],
     signers: List[Signer] = [],
     tagged: bool = False,
 ) -> bytes:
-
     return _cwt.encode(claims, key, nonce, recipients, signers, tagged)
 
 
 def encode_and_mac(
     claims: Union[Claims, Dict[int, Any], bytes],
     key: COSEKeyInterface,
-    recipients: Optional[List[RecipientInterface]] = None,
+    recipients: List[RecipientInterface] = [],
     tagged: bool = False,
 ) -> bytes:
-
     return _cwt.encode_and_mac(claims, key, recipients, tagged)
 
 
@@ -464,7 +461,6 @@ def encode_and_sign(
     signers: List[Signer] = [],
     tagged: bool = False,
 ) -> bytes:
-
     return _cwt.encode_and_sign(claims, key, signers, tagged)
 
 
@@ -472,10 +468,9 @@ def encode_and_encrypt(
     claims: Union[Claims, Dict[int, Any], bytes],
     key: COSEKeyInterface,
     nonce: bytes = b"",
-    recipients: Optional[List[RecipientInterface]] = None,
+    recipients: List[RecipientInterface] = [],
     tagged: bool = False,
 ) -> bytes:
-
     return _cwt.encode_and_encrypt(claims, key, nonce, recipients, tagged)
 
 
@@ -484,10 +479,8 @@ def decode(
     keys: Union[COSEKeyInterface, List[COSEKeyInterface]],
     no_verify: bool = False,
 ) -> Union[Dict[int, Any], bytes]:
-
     return _cwt.decode(data, keys, no_verify)
 
 
 def set_private_claim_names(claim_names: Dict[str, int]):
-
     return _cwt.set_private_claim_names(claim_names)
